import { Fragment } from 'react'

import Link from 'next/link'

import { useRouter } from 'next/dist/client/router'

import { Popover, Transition } from '@headlessui/react'
import { IconMenu2, IconX } from '@tabler/icons'

type NavbarConfig = {
  logo: {
    img: string
    alt?: string
  }
}

function Navbar({ logo }: NavbarConfig): JSX.Element {
  const { asPath } = useRouter()

  return (
    <Popover className="relative bg-white overflow-hidden mt-6">
      <nav
        className="relative max-w-7xl mx-auto flex items-center justify-between px-4 sm:px-6 "
        aria-label="Global"
      >
        <div className="flex items-center flex-1">
          <div className="flex items-center justify-between w-full md:w-auto">
            <Link href={'/'}>
              <img
                className="h-8 w-auto flex items-center hover:cursor-pointer"
                src={logo.img}
                alt={logo.alt ? logo.alt : 'Logo'}
              />
            </Link>
            <div className="-mr-2 flex items-center md:hidden">
              <Popover.Button className="bg-white rounded-md p-2 inline-flex items-center justify-center text-gray-400 hover:text-gray-500 hover:bg-gray-100 focus:outline-none focus:ring-2 focus:ring-inset focus:ring-indigo-500">
                <span className="sr-only">Open main menu</span>
                <IconMenu2 className="h-6 w-6" aria-hidden="true" />
              </Popover.Button>
            </div>
          </div>
          <div className="hidden md:block md:ml-10 md:space-x-10 flex">
              <Link href={'/ressources'} passHref legacyBehavior>
                <a
                  className={'font-medium text-gray-500 hover:text-gray-900'}
                >
                Plattformen &amp; Basisdienste
                </a>
              </Link>
            </div>
          </div>
          <div className="hidden md:block text-right flex items-center">
            {/* right side
          <a
            key={item.name}
            href={item.href}
            className="font-medium text-gray-500 hover:text-gray-900"
          >
            {item.name}
          </a>
          */}
          </div>
        </nav>

        <Transition
          as={Fragment}
          enter="duration-150 ease-out"
          enterFrom="opacity-0 scale-95"
          enterTo="opacity-100 scale-100"
          leave="duration-100 ease-in"
          leaveFrom="opacity-100 scale-100"
          leaveTo="opacity-0 scale-95"
        >
          <Popover.Panel
            focus
            className="absolute z-10 top-0 inset-x-0 p-2 transition transform origin-top-right md:hidden"
          >
            <div className="rounded-lg shadow-md bg-white ring-1 ring-black ring-opacity-5 overflow-hidden">
              <div className="px-5 pt-4 flex items-center justify-between">
                <div>
                  <Link href={'/'}>
                    <img
                      className="h-8 w-auto"
                      src={logo.img}
                      alt={logo.alt ? logo.alt : 'Logo'}
                    />
                  </Link>
                </div>
                <div className="-mr-2">
                  <Popover.Button className="bg-white rounded-md p-2 inline-flex items-center justify-center text-gray-400 hover:text-gray-500 hover:bg-gray-100 focus:outline-none focus:ring-2 focus:ring-inset focus:ring-indigo-500">
                    <span className="sr-only">Close main menu</span>
                    <IconX className="h-6 w-6" aria-hidden="true" />
                  </Popover.Button>
                </div>
              </div>
              <div className="px-2 pt-2 pb-3 space-y-1">
                <Link href={'/resources'} passHref legacyBehavior>
                  <a
                    className={'font-medium text-gray-500 hover:text-gray-900'}
                  >
                  Plattformen & Basisdienste
                  </a>
                </Link>
              </div>

              {/*
            <a
              key={item.name}
              href={item.href}
              className="block px-3 py-2 rounded-md text-base font-medium text-gray-700 hover:text-gray-900 hover:bg-gray-50"
            >
              {item.name}
            </a>
            */}
            </div>
          </Popover.Panel>
        </Transition>
      </Popover>
    )
}

export default Navbar
